# pylint: disable=missing-docstring
import json
import os.path
import pathlib
import unittest

import aas_core3.xmlization as aas_xmlization
import aas_core3.jsonization as aas_jsonization

import aas_core3_protobuf.pbization as aas_pbization


class TestEndToEnd(unittest.TestCase):
    def test_on_test_data_contained_in_environment(self) -> None:
        this_file = pathlib.Path(os.path.realpath(__file__))
        expected_dir = this_file.parent.parent / "test_data/Xml"

        for xml_path in sorted(expected_dir.glob("*/**/*.xml")):
            instance = aas_xmlization.from_file(xml_path)

            # NOTE (mristin):
            # We canonicalize the instance as JSON for easier debugging — it is quite
            # hard to diff two XML documents as texts.
            expected_json = json.dumps(
                aas_jsonization.to_jsonable(instance), sort_keys=True, indent=2
            )

            instance_pb = aas_pbization.to_pb(instance)

            data = instance_pb.SerializeToString()

            another_instance_pb = instance_pb.__class__.FromString(data)

            another_instance = aas_pbization.from_pb(another_instance_pb)

            got_json = json.dumps(
                aas_jsonization.to_jsonable(another_instance), sort_keys=True, indent=2
            )

            self.assertEqual(
                expected_json, got_json, f"Round trip for the example: {xml_path}"
            )


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: types.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 3, "", "types.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0btypes.proto\x12\taas_core3"\x9c\x02\n\tExtension\x12.\n\x0bsemantic_id\x18\x01 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x00\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x02 \x03(\x0b\x32\x14.aas_core3.Reference\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x32\n\nvalue_type\x18\x04 \x01(\x0e\x32\x19.aas_core3.DataTypeDefXsdH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\'\n\trefers_to\x18\x06 \x03(\x0b\x32\x14.aas_core3.ReferenceB\x0e\n\x0c_semantic_idB\r\n\x0b_value_typeB\x08\n\x06_value"\x8f\x02\n\x19\x41\x64ministrativeInformation\x12J\n\x1c\x65mbedded_data_specifications\x18\x01 \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12\x14\n\x07version\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08revision\x18\x03 \x01(\tH\x01\x88\x01\x01\x12*\n\x07\x63reator\x18\x04 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x18\n\x0btemplate_id\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\n\n\x08_versionB\x0b\n\t_revisionB\n\n\x08_creatorB\x0e\n\x0c_template_id"\xcf\x02\n\tQualifier\x12.\n\x0bsemantic_id\x18\x01 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x00\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x02 \x03(\x0b\x32\x14.aas_core3.Reference\x12+\n\x04kind\x18\x03 \x01(\x0e\x32\x18.aas_core3.QualifierKindH\x01\x88\x01\x01\x12\x0c\n\x04type\x18\x04 \x01(\t\x12-\n\nvalue_type\x18\x05 \x01(\x0e\x32\x19.aas_core3.DataTypeDefXsd\x12\x12\n\x05value\x18\x06 \x01(\tH\x02\x88\x01\x01\x12+\n\x08value_id\x18\x07 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x03\x88\x01\x01\x42\x0e\n\x0c_semantic_idB\x07\n\x05_kindB\x08\n\x06_valueB\x0b\n\t_value_id"\xc6\x04\n\x18\x41ssetAdministrationShell\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12\x41\n\x0e\x61\x64ministration\x18\x06 \x01(\x0b\x32$.aas_core3.AdministrativeInformationH\x02\x88\x01\x01\x12\n\n\x02id\x18\x07 \x01(\t\x12J\n\x1c\x65mbedded_data_specifications\x18\x08 \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12/\n\x0c\x64\x65rived_from\x18\t \x01(\x0b\x32\x14.aas_core3.ReferenceH\x03\x88\x01\x01\x12\x36\n\x11\x61sset_information\x18\n \x01(\x0b\x32\x1b.aas_core3.AssetInformation\x12\'\n\tsubmodels\x18\x0b \x03(\x0b\x32\x14.aas_core3.ReferenceB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x11\n\x0f_administrationB\x0f\n\r_derived_from"\x99\x02\n\x10\x41ssetInformation\x12(\n\nasset_kind\x18\x01 \x01(\x0e\x32\x14.aas_core3.AssetKind\x12\x1c\n\x0fglobal_asset_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x36\n\x12specific_asset_ids\x18\x03 \x03(\x0b\x32\x1a.aas_core3.SpecificAssetId\x12\x17\n\nasset_type\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x11\x64\x65\x66\x61ult_thumbnail\x18\x05 \x01(\x0b\x32\x13.aas_core3.ResourceH\x02\x88\x01\x01\x42\x12\n\x10_global_asset_idB\r\n\x0b_asset_typeB\x14\n\x12_default_thumbnail"D\n\x08Resource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x19\n\x0c\x63ontent_type\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_content_type"\xf7\x01\n\x0fSpecificAssetId\x12.\n\x0bsemantic_id\x18\x01 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x00\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x02 \x03(\x0b\x32\x14.aas_core3.Reference\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\x12\x36\n\x13\x65xternal_subject_id\x18\x05 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x01\x88\x01\x01\x42\x0e\n\x0c_semantic_idB\x16\n\x14_external_subject_id"\xaa\x05\n\x08Submodel\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12\x41\n\x0e\x61\x64ministration\x18\x06 \x01(\x0b\x32$.aas_core3.AdministrativeInformationH\x02\x88\x01\x01\x12\n\n\x02id\x18\x07 \x01(\t\x12+\n\x04kind\x18\x08 \x01(\x0e\x32\x18.aas_core3.ModellingKindH\x03\x88\x01\x01\x12.\n\x0bsemantic_id\x18\t \x01(\x0b\x32\x14.aas_core3.ReferenceH\x04\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\n \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x0b \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\x0c \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12<\n\x11submodel_elements\x18\r \x03(\x0b\x32!.aas_core3.SubmodelElement_choiceB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x11\n\x0f_administrationB\x07\n\x05_kindB\x0e\n\x0c_semantic_id"\xaa\x04\n\x13RelationshipElement\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12#\n\x05\x66irst\x18\n \x01(\x0b\x32\x14.aas_core3.Reference\x12$\n\x06second\x18\x0b \x01(\x0b\x32\x14.aas_core3.ReferenceB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_id"\xb9\x06\n\x13SubmodelElementList\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12\x1b\n\x0eorder_relevant\x18\n \x01(\x08H\x03\x88\x01\x01\x12;\n\x18semantic_id_list_element\x18\x0b \x01(\x0b\x32\x14.aas_core3.ReferenceH\x04\x88\x01\x01\x12?\n\x17type_value_list_element\x18\x0c \x01(\x0e\x32\x1e.aas_core3.AasSubmodelElements\x12?\n\x17value_type_list_element\x18\r \x01(\x0e\x32\x19.aas_core3.DataTypeDefXsdH\x05\x88\x01\x01\x12\x30\n\x05value\x18\x0e \x03(\x0b\x32!.aas_core3.SubmodelElement_choiceB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_idB\x11\n\x0f_order_relevantB\x1b\n\x19_semantic_id_list_elementB\x1a\n\x18_value_type_list_element"\x97\x04\n\x19SubmodelElementCollection\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12\x30\n\x05value\x18\n \x03(\x0b\x32!.aas_core3.SubmodelElement_choiceB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_id"\xdb\x04\n\x08Property\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12-\n\nvalue_type\x18\n \x01(\x0e\x32\x19.aas_core3.DataTypeDefXsd\x12\x12\n\x05value\x18\x0b \x01(\tH\x03\x88\x01\x01\x12+\n\x08value_id\x18\x0c \x01(\x0b\x32\x14.aas_core3.ReferenceH\x04\x88\x01\x01\x42\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_idB\x08\n\x06_valueB\x0b\n\t_value_id"\xc9\x04\n\x15MultiLanguageProperty\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12,\n\x05value\x18\n \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12+\n\x08value_id\x18\x0b \x01(\x0b\x32\x14.aas_core3.ReferenceH\x03\x88\x01\x01\x42\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_idB\x0b\n\t_value_id"\xb4\x04\n\x05Range\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12-\n\nvalue_type\x18\n \x01(\x0e\x32\x19.aas_core3.DataTypeDefXsd\x12\x10\n\x03min\x18\x0b \x01(\tH\x03\x88\x01\x01\x12\x10\n\x03max\x18\x0c \x01(\tH\x04\x88\x01\x01\x42\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_idB\x06\n\x04_minB\x06\n\x04_max"\x90\x04\n\x10ReferenceElement\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12(\n\x05value\x18\n \x01(\x0b\x32\x14.aas_core3.ReferenceH\x03\x88\x01\x01\x42\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_idB\x08\n\x06_value"\x84\x04\n\x04\x42lob\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12\x12\n\x05value\x18\n \x01(\x0cH\x03\x88\x01\x01\x12\x14\n\x0c\x63ontent_type\x18\x0b \x01(\tB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_idB\x08\n\x06_value"\x84\x04\n\x04\x46ile\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12\x12\n\x05value\x18\n \x01(\tH\x03\x88\x01\x01\x12\x14\n\x0c\x63ontent_type\x18\x0b \x01(\tB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_idB\x08\n\x06_value"\xe7\x04\n\x1c\x41nnotatedRelationshipElement\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12#\n\x05\x66irst\x18\n \x01(\x0b\x32\x14.aas_core3.Reference\x12$\n\x06second\x18\x0b \x01(\x0b\x32\x14.aas_core3.Reference\x12\x32\n\x0b\x61nnotations\x18\x0c \x03(\x0b\x32\x1d.aas_core3.DataElement_choiceB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_id"\x9f\x05\n\x06\x45ntity\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12\x35\n\nstatements\x18\n \x03(\x0b\x32!.aas_core3.SubmodelElement_choice\x12*\n\x0b\x65ntity_type\x18\x0b \x01(\x0e\x32\x15.aas_core3.EntityType\x12\x1c\n\x0fglobal_asset_id\x18\x0c \x01(\tH\x03\x88\x01\x01\x12\x36\n\x12specific_asset_ids\x18\r \x03(\x0b\x32\x1a.aas_core3.SpecificAssetIdB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_idB\x12\n\x10_global_asset_id"\x9e\x03\n\x0c\x45ventPayload\x12$\n\x06source\x18\x01 \x01(\x0b\x32\x14.aas_core3.Reference\x12\x35\n\x12source_semantic_id\x18\x02 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x00\x88\x01\x01\x12\x32\n\x14observable_reference\x18\x03 \x01(\x0b\x32\x14.aas_core3.Reference\x12\x39\n\x16observable_semantic_id\x18\x04 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x01\x88\x01\x01\x12\x12\n\x05topic\x18\x05 \x01(\tH\x02\x88\x01\x01\x12-\n\nsubject_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x03\x88\x01\x01\x12\x12\n\ntime_stamp\x18\x07 \x01(\t\x12\x14\n\x07payload\x18\x08 \x01(\x0cH\x04\x88\x01\x01\x42\x15\n\x13_source_semantic_idB\x19\n\x17_observable_semantic_idB\x08\n\x06_topicB\r\n\x0b_subject_idB\n\n\x08_payload"\xcc\x06\n\x11\x42\x61sicEventElement\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12&\n\x08observed\x18\n \x01(\x0b\x32\x14.aas_core3.Reference\x12\'\n\tdirection\x18\x0b \x01(\x0e\x32\x14.aas_core3.Direction\x12&\n\x05state\x18\x0c \x01(\x0e\x32\x17.aas_core3.StateOfEvent\x12\x1a\n\rmessage_topic\x18\r \x01(\tH\x03\x88\x01\x01\x12\x31\n\x0emessage_broker\x18\x0e \x01(\x0b\x32\x14.aas_core3.ReferenceH\x04\x88\x01\x01\x12\x18\n\x0blast_update\x18\x0f \x01(\tH\x05\x88\x01\x01\x12\x19\n\x0cmin_interval\x18\x10 \x01(\tH\x06\x88\x01\x01\x12\x19\n\x0cmax_interval\x18\x11 \x01(\tH\x07\x88\x01\x01\x42\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_idB\x10\n\x0e_message_topicB\x11\n\x0f_message_brokerB\x0e\n\x0c_last_updateB\x0f\n\r_min_intervalB\x0f\n\r_max_interval"\xfe\x04\n\tOperation\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12\x35\n\x0finput_variables\x18\n \x03(\x0b\x32\x1c.aas_core3.OperationVariable\x12\x36\n\x10output_variables\x18\x0b \x03(\x0b\x32\x1c.aas_core3.OperationVariable\x12\x38\n\x12inoutput_variables\x18\x0c \x03(\x0b\x32\x1c.aas_core3.OperationVariableB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_id"E\n\x11OperationVariable\x12\x30\n\x05value\x18\x01 \x01(\x0b\x32!.aas_core3.SubmodelElement_choice"\xd6\x03\n\nCapability\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12.\n\x0bsemantic_id\x18\x06 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x02\x88\x01\x01\x12\x37\n\x19supplemental_semantic_ids\x18\x07 \x03(\x0b\x32\x14.aas_core3.Reference\x12(\n\nqualifiers\x18\x08 \x03(\x0b\x32\x14.aas_core3.Qualifier\x12J\n\x1c\x65mbedded_data_specifications\x18\t \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecificationB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x0e\n\x0c_semantic_id"\xc7\x03\n\x12\x43onceptDescription\x12(\n\nextensions\x18\x01 \x03(\x0b\x32\x14.aas_core3.Extension\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08id_short\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x33\n\x0c\x64isplay_name\x18\x04 \x03(\x0b\x32\x1d.aas_core3.LangStringNameType\x12\x32\n\x0b\x64\x65scription\x18\x05 \x03(\x0b\x32\x1d.aas_core3.LangStringTextType\x12\x41\n\x0e\x61\x64ministration\x18\x06 \x01(\x0b\x32$.aas_core3.AdministrativeInformationH\x02\x88\x01\x01\x12\n\n\x02id\x18\x07 \x01(\t\x12J\n\x1c\x65mbedded_data_specifications\x18\x08 \x03(\x0b\x32$.aas_core3.EmbeddedDataSpecification\x12(\n\nis_case_of\x18\t \x03(\x0b\x32\x14.aas_core3.ReferenceB\x0b\n\t_categoryB\x0b\n\t_id_shortB\x11\n\x0f_administration"\xa4\x01\n\tReference\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.aas_core3.ReferenceTypes\x12\x37\n\x14referred_semantic_id\x18\x02 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x00\x88\x01\x01\x12\x1c\n\x04keys\x18\x03 \x03(\x0b\x32\x0e.aas_core3.KeyB\x17\n\x15_referred_semantic_id"7\n\x03Key\x12!\n\x04type\x18\x01 \x01(\x0e\x32\x13.aas_core3.KeyTypes\x12\r\n\x05value\x18\x02 \x01(\t"4\n\x12LangStringNameType\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t"4\n\x12LangStringTextType\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t"\xbc\x01\n\x0b\x45nvironment\x12H\n\x1b\x61sset_administration_shells\x18\x01 \x03(\x0b\x32#.aas_core3.AssetAdministrationShell\x12&\n\tsubmodels\x18\x02 \x03(\x0b\x32\x13.aas_core3.Submodel\x12;\n\x14\x63oncept_descriptions\x18\x03 \x03(\x0b\x32\x1d.aas_core3.ConceptDescription"\x9d\x01\n\x19\x45mbeddedDataSpecification\x12N\n\x1a\x64\x61ta_specification_content\x18\x01 \x01(\x0b\x32*.aas_core3.DataSpecificationContent_choice\x12\x30\n\x12\x64\x61ta_specification\x18\x02 \x01(\x0b\x32\x14.aas_core3.Reference"?\n\tLevelType\x12\x0b\n\x03min\x18\x01 \x01(\x08\x12\x0b\n\x03nom\x18\x02 \x01(\x08\x12\x0b\n\x03typ\x18\x03 \x01(\x08\x12\x0b\n\x03max\x18\x04 \x01(\x08"K\n\x12ValueReferencePair\x12\r\n\x05value\x18\x01 \x01(\t\x12&\n\x08value_id\x18\x02 \x01(\x0b\x32\x14.aas_core3.Reference"I\n\tValueList\x12<\n\x15value_reference_pairs\x18\x01 \x03(\x0b\x32\x1d.aas_core3.ValueReferencePair"E\n#LangStringPreferredNameTypeIec61360\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t"A\n\x1fLangStringShortNameTypeIec61360\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t"B\n LangStringDefinitionTypeIec61360\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t"\x9d\x05\n\x19\x44\x61taSpecificationIec61360\x12\x46\n\x0epreferred_name\x18\x01 \x03(\x0b\x32..aas_core3.LangStringPreferredNameTypeIec61360\x12>\n\nshort_name\x18\x02 \x03(\x0b\x32*.aas_core3.LangStringShortNameTypeIec61360\x12\x11\n\x04unit\x18\x03 \x01(\tH\x00\x88\x01\x01\x12*\n\x07unit_id\x18\x04 \x01(\x0b\x32\x14.aas_core3.ReferenceH\x01\x88\x01\x01\x12!\n\x14source_of_definition\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06symbol\x18\x06 \x01(\tH\x03\x88\x01\x01\x12\x33\n\tdata_type\x18\x07 \x01(\x0e\x32\x1b.aas_core3.DataTypeIec61360H\x04\x88\x01\x01\x12?\n\ndefinition\x18\x08 \x03(\x0b\x32+.aas_core3.LangStringDefinitionTypeIec61360\x12\x19\n\x0cvalue_format\x18\t \x01(\tH\x05\x88\x01\x01\x12-\n\nvalue_list\x18\n \x01(\x0b\x32\x14.aas_core3.ValueListH\x06\x88\x01\x01\x12\x12\n\x05value\x18\x0b \x01(\tH\x07\x88\x01\x01\x12-\n\nlevel_type\x18\x0c \x01(\x0b\x32\x14.aas_core3.LevelTypeH\x08\x88\x01\x01\x42\x07\n\x05_unitB\n\n\x08_unit_idB\x17\n\x15_source_of_definitionB\t\n\x07_symbolB\x0c\n\n_data_typeB\x0f\n\r_value_formatB\r\n\x0b_value_listB\x08\n\x06_valueB\r\n\x0b_level_type"\xbe\x07\n\x13HasSemantics_choice\x12>\n\x14relationship_element\x18\x01 \x01(\x0b\x32\x1e.aas_core3.RelationshipElementH\x00\x12Q\n\x1e\x61nnotated_relationship_element\x18\x02 \x01(\x0b\x32\'.aas_core3.AnnotatedRelationshipElementH\x00\x12;\n\x13\x62\x61sic_event_element\x18\x03 \x01(\x0b\x32\x1c.aas_core3.BasicEventElementH\x00\x12\x1f\n\x04\x62lob\x18\x04 \x01(\x0b\x32\x0f.aas_core3.BlobH\x00\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x15.aas_core3.CapabilityH\x00\x12#\n\x06\x65ntity\x18\x06 \x01(\x0b\x32\x11.aas_core3.EntityH\x00\x12)\n\textension\x18\x07 \x01(\x0b\x32\x14.aas_core3.ExtensionH\x00\x12\x1f\n\x04\x66ile\x18\x08 \x01(\x0b\x32\x0f.aas_core3.FileH\x00\x12\x43\n\x17multi_language_property\x18\t \x01(\x0b\x32 .aas_core3.MultiLanguagePropertyH\x00\x12)\n\toperation\x18\n \x01(\x0b\x32\x14.aas_core3.OperationH\x00\x12\'\n\x08property\x18\x0b \x01(\x0b\x32\x13.aas_core3.PropertyH\x00\x12)\n\tqualifier\x18\x0c \x01(\x0b\x32\x14.aas_core3.QualifierH\x00\x12!\n\x05range\x18\r \x01(\x0b\x32\x10.aas_core3.RangeH\x00\x12\x38\n\x11reference_element\x18\x0e \x01(\x0b\x32\x1b.aas_core3.ReferenceElementH\x00\x12\x37\n\x11specific_asset_id\x18\x0f \x01(\x0b\x32\x1a.aas_core3.SpecificAssetIdH\x00\x12\'\n\x08submodel\x18\x10 \x01(\x0b\x32\x13.aas_core3.SubmodelH\x00\x12K\n\x1bsubmodel_element_collection\x18\x11 \x01(\x0b\x32$.aas_core3.SubmodelElementCollectionH\x00\x12?\n\x15submodel_element_list\x18\x12 \x01(\x0b\x32\x1e.aas_core3.SubmodelElementListH\x00\x42\x07\n\x05value"\xb9\x07\n\x14HasExtensions_choice\x12>\n\x14relationship_element\x18\x01 \x01(\x0b\x32\x1e.aas_core3.RelationshipElementH\x00\x12Q\n\x1e\x61nnotated_relationship_element\x18\x02 \x01(\x0b\x32\'.aas_core3.AnnotatedRelationshipElementH\x00\x12I\n\x1a\x61sset_administration_shell\x18\x03 \x01(\x0b\x32#.aas_core3.AssetAdministrationShellH\x00\x12;\n\x13\x62\x61sic_event_element\x18\x04 \x01(\x0b\x32\x1c.aas_core3.BasicEventElementH\x00\x12\x1f\n\x04\x62lob\x18\x05 \x01(\x0b\x32\x0f.aas_core3.BlobH\x00\x12+\n\ncapability\x18\x06 \x01(\x0b\x32\x15.aas_core3.CapabilityH\x00\x12<\n\x13\x63oncept_description\x18\x07 \x01(\x0b\x32\x1d.aas_core3.ConceptDescriptionH\x00\x12#\n\x06\x65ntity\x18\x08 \x01(\x0b\x32\x11.aas_core3.EntityH\x00\x12\x1f\n\x04\x66ile\x18\t \x01(\x0b\x32\x0f.aas_core3.FileH\x00\x12\x43\n\x17multi_language_property\x18\n \x01(\x0b\x32 .aas_core3.MultiLanguagePropertyH\x00\x12)\n\toperation\x18\x0b \x01(\x0b\x32\x14.aas_core3.OperationH\x00\x12\'\n\x08property\x18\x0c \x01(\x0b\x32\x13.aas_core3.PropertyH\x00\x12!\n\x05range\x18\r \x01(\x0b\x32\x10.aas_core3.RangeH\x00\x12\x38\n\x11reference_element\x18\x0e \x01(\x0b\x32\x1b.aas_core3.ReferenceElementH\x00\x12\'\n\x08submodel\x18\x0f \x01(\x0b\x32\x13.aas_core3.SubmodelH\x00\x12K\n\x1bsubmodel_element_collection\x18\x10 \x01(\x0b\x32$.aas_core3.SubmodelElementCollectionH\x00\x12?\n\x15submodel_element_list\x18\x11 \x01(\x0b\x32\x1e.aas_core3.SubmodelElementListH\x00\x42\x07\n\x05value"\xb5\x07\n\x10Referable_choice\x12>\n\x14relationship_element\x18\x01 \x01(\x0b\x32\x1e.aas_core3.RelationshipElementH\x00\x12Q\n\x1e\x61nnotated_relationship_element\x18\x02 \x01(\x0b\x32\'.aas_core3.AnnotatedRelationshipElementH\x00\x12I\n\x1a\x61sset_administration_shell\x18\x03 \x01(\x0b\x32#.aas_core3.AssetAdministrationShellH\x00\x12;\n\x13\x62\x61sic_event_element\x18\x04 \x01(\x0b\x32\x1c.aas_core3.BasicEventElementH\x00\x12\x1f\n\x04\x62lob\x18\x05 \x01(\x0b\x32\x0f.aas_core3.BlobH\x00\x12+\n\ncapability\x18\x06 \x01(\x0b\x32\x15.aas_core3.CapabilityH\x00\x12<\n\x13\x63oncept_description\x18\x07 \x01(\x0b\x32\x1d.aas_core3.ConceptDescriptionH\x00\x12#\n\x06\x65ntity\x18\x08 \x01(\x0b\x32\x11.aas_core3.EntityH\x00\x12\x1f\n\x04\x66ile\x18\t \x01(\x0b\x32\x0f.aas_core3.FileH\x00\x12\x43\n\x17multi_language_property\x18\n \x01(\x0b\x32 .aas_core3.MultiLanguagePropertyH\x00\x12)\n\toperation\x18\x0b \x01(\x0b\x32\x14.aas_core3.OperationH\x00\x12\'\n\x08property\x18\x0c \x01(\x0b\x32\x13.aas_core3.PropertyH\x00\x12!\n\x05range\x18\r \x01(\x0b\x32\x10.aas_core3.RangeH\x00\x12\x38\n\x11reference_element\x18\x0e \x01(\x0b\x32\x1b.aas_core3.ReferenceElementH\x00\x12\'\n\x08submodel\x18\x0f \x01(\x0b\x32\x13.aas_core3.SubmodelH\x00\x12K\n\x1bsubmodel_element_collection\x18\x10 \x01(\x0b\x32$.aas_core3.SubmodelElementCollectionH\x00\x12?\n\x15submodel_element_list\x18\x11 \x01(\x0b\x32\x1e.aas_core3.SubmodelElementListH\x00\x42\x07\n\x05value"\xd0\x01\n\x13Identifiable_choice\x12I\n\x1a\x61sset_administration_shell\x18\x01 \x01(\x0b\x32#.aas_core3.AssetAdministrationShellH\x00\x12<\n\x13\x63oncept_description\x18\x02 \x01(\x0b\x32\x1d.aas_core3.ConceptDescriptionH\x00\x12\'\n\x08submodel\x18\x03 \x01(\x0b\x32\x13.aas_core3.SubmodelH\x00\x42\x07\n\x05value"B\n\x0eHasKind_choice\x12\'\n\x08submodel\x18\x01 \x01(\x0b\x32\x13.aas_core3.SubmodelH\x00\x42\x07\n\x05value"\x8c\x08\n\x1bHasDataSpecification_choice\x12J\n\x1a\x61\x64ministrative_information\x18\x01 \x01(\x0b\x32$.aas_core3.AdministrativeInformationH\x00\x12>\n\x14relationship_element\x18\x02 \x01(\x0b\x32\x1e.aas_core3.RelationshipElementH\x00\x12Q\n\x1e\x61nnotated_relationship_element\x18\x03 \x01(\x0b\x32\'.aas_core3.AnnotatedRelationshipElementH\x00\x12I\n\x1a\x61sset_administration_shell\x18\x04 \x01(\x0b\x32#.aas_core3.AssetAdministrationShellH\x00\x12;\n\x13\x62\x61sic_event_element\x18\x05 \x01(\x0b\x32\x1c.aas_core3.BasicEventElementH\x00\x12\x1f\n\x04\x62lob\x18\x06 \x01(\x0b\x32\x0f.aas_core3.BlobH\x00\x12+\n\ncapability\x18\x07 \x01(\x0b\x32\x15.aas_core3.CapabilityH\x00\x12<\n\x13\x63oncept_description\x18\x08 \x01(\x0b\x32\x1d.aas_core3.ConceptDescriptionH\x00\x12#\n\x06\x65ntity\x18\t \x01(\x0b\x32\x11.aas_core3.EntityH\x00\x12\x1f\n\x04\x66ile\x18\n \x01(\x0b\x32\x0f.aas_core3.FileH\x00\x12\x43\n\x17multi_language_property\x18\x0b \x01(\x0b\x32 .aas_core3.MultiLanguagePropertyH\x00\x12)\n\toperation\x18\x0c \x01(\x0b\x32\x14.aas_core3.OperationH\x00\x12\'\n\x08property\x18\r \x01(\x0b\x32\x13.aas_core3.PropertyH\x00\x12!\n\x05range\x18\x0e \x01(\x0b\x32\x10.aas_core3.RangeH\x00\x12\x38\n\x11reference_element\x18\x0f \x01(\x0b\x32\x1b.aas_core3.ReferenceElementH\x00\x12\'\n\x08submodel\x18\x10 \x01(\x0b\x32\x13.aas_core3.SubmodelH\x00\x12K\n\x1bsubmodel_element_collection\x18\x11 \x01(\x0b\x32$.aas_core3.SubmodelElementCollectionH\x00\x12?\n\x15submodel_element_list\x18\x12 \x01(\x0b\x32\x1e.aas_core3.SubmodelElementListH\x00\x42\x07\n\x05value"\xae\x06\n\x12Qualifiable_choice\x12>\n\x14relationship_element\x18\x01 \x01(\x0b\x32\x1e.aas_core3.RelationshipElementH\x00\x12Q\n\x1e\x61nnotated_relationship_element\x18\x02 \x01(\x0b\x32\'.aas_core3.AnnotatedRelationshipElementH\x00\x12;\n\x13\x62\x61sic_event_element\x18\x03 \x01(\x0b\x32\x1c.aas_core3.BasicEventElementH\x00\x12\x1f\n\x04\x62lob\x18\x04 \x01(\x0b\x32\x0f.aas_core3.BlobH\x00\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x15.aas_core3.CapabilityH\x00\x12#\n\x06\x65ntity\x18\x06 \x01(\x0b\x32\x11.aas_core3.EntityH\x00\x12\x1f\n\x04\x66ile\x18\x07 \x01(\x0b\x32\x0f.aas_core3.FileH\x00\x12\x43\n\x17multi_language_property\x18\x08 \x01(\x0b\x32 .aas_core3.MultiLanguagePropertyH\x00\x12)\n\toperation\x18\t \x01(\x0b\x32\x14.aas_core3.OperationH\x00\x12\'\n\x08property\x18\n \x01(\x0b\x32\x13.aas_core3.PropertyH\x00\x12!\n\x05range\x18\x0b \x01(\x0b\x32\x10.aas_core3.RangeH\x00\x12\x38\n\x11reference_element\x18\x0c \x01(\x0b\x32\x1b.aas_core3.ReferenceElementH\x00\x12\'\n\x08submodel\x18\r \x01(\x0b\x32\x13.aas_core3.SubmodelH\x00\x12K\n\x1bsubmodel_element_collection\x18\x0e \x01(\x0b\x32$.aas_core3.SubmodelElementCollectionH\x00\x12?\n\x15submodel_element_list\x18\x0f \x01(\x0b\x32\x1e.aas_core3.SubmodelElementListH\x00\x42\x07\n\x05value"\x89\x06\n\x16SubmodelElement_choice\x12>\n\x14relationship_element\x18\x01 \x01(\x0b\x32\x1e.aas_core3.RelationshipElementH\x00\x12Q\n\x1e\x61nnotated_relationship_element\x18\x02 \x01(\x0b\x32\'.aas_core3.AnnotatedRelationshipElementH\x00\x12;\n\x13\x62\x61sic_event_element\x18\x03 \x01(\x0b\x32\x1c.aas_core3.BasicEventElementH\x00\x12\x1f\n\x04\x62lob\x18\x04 \x01(\x0b\x32\x0f.aas_core3.BlobH\x00\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x15.aas_core3.CapabilityH\x00\x12#\n\x06\x65ntity\x18\x06 \x01(\x0b\x32\x11.aas_core3.EntityH\x00\x12\x1f\n\x04\x66ile\x18\x07 \x01(\x0b\x32\x0f.aas_core3.FileH\x00\x12\x43\n\x17multi_language_property\x18\x08 \x01(\x0b\x32 .aas_core3.MultiLanguagePropertyH\x00\x12)\n\toperation\x18\t \x01(\x0b\x32\x14.aas_core3.OperationH\x00\x12\'\n\x08property\x18\n \x01(\x0b\x32\x13.aas_core3.PropertyH\x00\x12!\n\x05range\x18\x0b \x01(\x0b\x32\x10.aas_core3.RangeH\x00\x12\x38\n\x11reference_element\x18\x0c \x01(\x0b\x32\x1b.aas_core3.ReferenceElementH\x00\x12K\n\x1bsubmodel_element_collection\x18\r \x01(\x0b\x32$.aas_core3.SubmodelElementCollectionH\x00\x12?\n\x15submodel_element_list\x18\x0e \x01(\x0b\x32\x1e.aas_core3.SubmodelElementListH\x00\x42\x07\n\x05value"\xb8\x01\n\x1aRelationshipElement_choice\x12>\n\x14relationship_element\x18\x01 \x01(\x0b\x32\x1e.aas_core3.RelationshipElementH\x00\x12Q\n\x1e\x61nnotated_relationship_element\x18\x02 \x01(\x0b\x32\'.aas_core3.AnnotatedRelationshipElementH\x00\x42\x07\n\x05value"\xaa\x02\n\x12\x44\x61taElement_choice\x12\x1f\n\x04\x62lob\x18\x01 \x01(\x0b\x32\x0f.aas_core3.BlobH\x00\x12\x1f\n\x04\x66ile\x18\x02 \x01(\x0b\x32\x0f.aas_core3.FileH\x00\x12\x43\n\x17multi_language_property\x18\x03 \x01(\x0b\x32 .aas_core3.MultiLanguagePropertyH\x00\x12\'\n\x08property\x18\x04 \x01(\x0b\x32\x13.aas_core3.PropertyH\x00\x12!\n\x05range\x18\x05 \x01(\x0b\x32\x10.aas_core3.RangeH\x00\x12\x38\n\x11reference_element\x18\x06 \x01(\x0b\x32\x1b.aas_core3.ReferenceElementH\x00\x42\x07\n\x05value"[\n\x13\x45ventElement_choice\x12;\n\x13\x62\x61sic_event_element\x18\x01 \x01(\x0b\x32\x1c.aas_core3.BasicEventElementH\x00\x42\x07\n\x05value"\xc4\x03\n\x19\x41\x62stractLangString_choice\x12\\\n%lang_string_definition_type_iec_61360\x18\x01 \x01(\x0b\x32+.aas_core3.LangStringDefinitionTypeIec61360H\x00\x12>\n\x15lang_string_name_type\x18\x02 \x01(\x0b\x32\x1d.aas_core3.LangStringNameTypeH\x00\x12\x63\n)lang_string_preferred_name_type_iec_61360\x18\x03 \x01(\x0b\x32..aas_core3.LangStringPreferredNameTypeIec61360H\x00\x12[\n%lang_string_short_name_type_iec_61360\x18\x04 \x01(\x0b\x32*.aas_core3.LangStringShortNameTypeIec61360H\x00\x12>\n\x15lang_string_text_type\x18\x05 \x01(\x0b\x32\x1d.aas_core3.LangStringTextTypeH\x00\x42\x07\n\x05value"x\n\x1f\x44\x61taSpecificationContent_choice\x12L\n\x1c\x64\x61ta_specification_iec_61360\x18\x01 \x01(\x0b\x32$.aas_core3.DataSpecificationIec61360H\x00\x42\x07\n\x05value*f\n\rModellingKind\x12\x1d\n\x19Modellingkind_UNSPECIFIED\x10\x00\x12\x1a\n\x16Modellingkind_TEMPLATE\x10\x01\x12\x1a\n\x16Modellingkind_INSTANCE\x10\x02*\x9c\x01\n\rQualifierKind\x12\x1d\n\x19Qualifierkind_UNSPECIFIED\x10\x00\x12!\n\x1dQualifierkind_VALUE_QUALIFIER\x10\x01\x12#\n\x1fQualifierkind_CONCEPT_QUALIFIER\x10\x02\x12$\n Qualifierkind_TEMPLATE_QUALIFIER\x10\x03*p\n\tAssetKind\x12\x19\n\x15\x41ssetkind_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41ssetkind_TYPE\x10\x01\x12\x16\n\x12\x41ssetkind_INSTANCE\x10\x02\x12\x1c\n\x18\x41ssetkind_NOT_APPLICABLE\x10\x03*\xe8\x05\n\x13\x41\x61sSubmodelElements\x12#\n\x1f\x41\x61ssubmodelelements_UNSPECIFIED\x10\x00\x12\x36\n2Aassubmodelelements_ANNOTATED_RELATIONSHIP_ELEMENT\x10\x01\x12+\n\'Aassubmodelelements_BASIC_EVENT_ELEMENT\x10\x02\x12\x1c\n\x18\x41\x61ssubmodelelements_BLOB\x10\x03\x12"\n\x1e\x41\x61ssubmodelelements_CAPABILITY\x10\x04\x12$\n Aassubmodelelements_DATA_ELEMENT\x10\x05\x12\x1e\n\x1a\x41\x61ssubmodelelements_ENTITY\x10\x06\x12%\n!Aassubmodelelements_EVENT_ELEMENT\x10\x07\x12\x1c\n\x18\x41\x61ssubmodelelements_FILE\x10\x08\x12/\n+Aassubmodelelements_MULTI_LANGUAGE_PROPERTY\x10\t\x12!\n\x1d\x41\x61ssubmodelelements_OPERATION\x10\n\x12 \n\x1c\x41\x61ssubmodelelements_PROPERTY\x10\x0b\x12\x1d\n\x19\x41\x61ssubmodelelements_RANGE\x10\x0c\x12)\n%Aassubmodelelements_REFERENCE_ELEMENT\x10\r\x12,\n(Aassubmodelelements_RELATIONSHIP_ELEMENT\x10\x0e\x12(\n$Aassubmodelelements_SUBMODEL_ELEMENT\x10\x0f\x12-\n)Aassubmodelelements_SUBMODEL_ELEMENT_LIST\x10\x10\x12\x33\n/Aassubmodelelements_SUBMODEL_ELEMENT_COLLECTION\x10\x11*n\n\nEntityType\x12\x1a\n\x16\x45ntitytype_UNSPECIFIED\x10\x00\x12 \n\x1c\x45ntitytype_CO_MANAGED_ENTITY\x10\x01\x12"\n\x1e\x45ntitytype_SELF_MANAGED_ENTITY\x10\x02*Q\n\tDirection\x12\x19\n\x15\x44irection_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x44irection_INPUT\x10\x01\x12\x14\n\x10\x44irection_OUTPUT\x10\x02*W\n\x0cStateOfEvent\x12\x1c\n\x18Stateofevent_UNSPECIFIED\x10\x00\x12\x13\n\x0fStateofevent_ON\x10\x01\x12\x14\n\x10Stateofevent_OFF\x10\x02*{\n\x0eReferenceTypes\x12\x1e\n\x1aReferencetypes_UNSPECIFIED\x10\x00\x12%\n!Referencetypes_EXTERNAL_REFERENCE\x10\x01\x12"\n\x1eReferencetypes_MODEL_REFERENCE\x10\x02*\xec\x05\n\x08KeyTypes\x12\x18\n\x14Keytypes_UNSPECIFIED\x10\x00\x12+\n\'Keytypes_ANNOTATED_RELATIONSHIP_ELEMENT\x10\x01\x12\'\n#Keytypes_ASSET_ADMINISTRATION_SHELL\x10\x02\x12 \n\x1cKeytypes_BASIC_EVENT_ELEMENT\x10\x03\x12\x11\n\rKeytypes_BLOB\x10\x04\x12\x17\n\x13Keytypes_CAPABILITY\x10\x05\x12 \n\x1cKeytypes_CONCEPT_DESCRIPTION\x10\x06\x12\x19\n\x15Keytypes_DATA_ELEMENT\x10\x07\x12\x13\n\x0fKeytypes_ENTITY\x10\x08\x12\x1a\n\x16Keytypes_EVENT_ELEMENT\x10\t\x12\x11\n\rKeytypes_FILE\x10\n\x12\x1f\n\x1bKeytypes_FRAGMENT_REFERENCE\x10\x0b\x12\x1d\n\x19Keytypes_GLOBAL_REFERENCE\x10\x0c\x12\x19\n\x15Keytypes_IDENTIFIABLE\x10\r\x12$\n Keytypes_MULTI_LANGUAGE_PROPERTY\x10\x0e\x12\x16\n\x12Keytypes_OPERATION\x10\x0f\x12\x15\n\x11Keytypes_PROPERTY\x10\x10\x12\x12\n\x0eKeytypes_RANGE\x10\x11\x12\x16\n\x12Keytypes_REFERABLE\x10\x12\x12\x1e\n\x1aKeytypes_REFERENCE_ELEMENT\x10\x13\x12!\n\x1dKeytypes_RELATIONSHIP_ELEMENT\x10\x14\x12\x15\n\x11Keytypes_SUBMODEL\x10\x15\x12\x1d\n\x19Keytypes_SUBMODEL_ELEMENT\x10\x16\x12(\n$Keytypes_SUBMODEL_ELEMENT_COLLECTION\x10\x17\x12"\n\x1eKeytypes_SUBMODEL_ELEMENT_LIST\x10\x18*\xb9\x07\n\x0e\x44\x61taTypeDefXsd\x12\x1e\n\x1a\x44\x61tatypedefxsd_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x44\x61tatypedefxsd_ANY_URI\x10\x01\x12!\n\x1d\x44\x61tatypedefxsd_BASE_64_BINARY\x10\x02\x12\x1a\n\x16\x44\x61tatypedefxsd_BOOLEAN\x10\x03\x12\x17\n\x13\x44\x61tatypedefxsd_BYTE\x10\x04\x12\x17\n\x13\x44\x61tatypedefxsd_DATE\x10\x05\x12\x1c\n\x18\x44\x61tatypedefxsd_DATE_TIME\x10\x06\x12\x1a\n\x16\x44\x61tatypedefxsd_DECIMAL\x10\x07\x12\x19\n\x15\x44\x61tatypedefxsd_DOUBLE\x10\x08\x12\x1b\n\x17\x44\x61tatypedefxsd_DURATION\x10\t\x12\x18\n\x14\x44\x61tatypedefxsd_FLOAT\x10\n\x12\x18\n\x14\x44\x61tatypedefxsd_G_DAY\x10\x0b\x12\x1a\n\x16\x44\x61tatypedefxsd_G_MONTH\x10\x0c\x12\x1e\n\x1a\x44\x61tatypedefxsd_G_MONTH_DAY\x10\r\x12\x19\n\x15\x44\x61tatypedefxsd_G_YEAR\x10\x0e\x12\x1f\n\x1b\x44\x61tatypedefxsd_G_YEAR_MONTH\x10\x0f\x12\x1d\n\x19\x44\x61tatypedefxsd_HEX_BINARY\x10\x10\x12\x16\n\x12\x44\x61tatypedefxsd_INT\x10\x11\x12\x1a\n\x16\x44\x61tatypedefxsd_INTEGER\x10\x12\x12\x17\n\x13\x44\x61tatypedefxsd_LONG\x10\x13\x12#\n\x1f\x44\x61tatypedefxsd_NEGATIVE_INTEGER\x10\x14\x12\'\n#Datatypedefxsd_NON_NEGATIVE_INTEGER\x10\x15\x12\'\n#Datatypedefxsd_NON_POSITIVE_INTEGER\x10\x16\x12#\n\x1f\x44\x61tatypedefxsd_POSITIVE_INTEGER\x10\x17\x12\x18\n\x14\x44\x61tatypedefxsd_SHORT\x10\x18\x12\x19\n\x15\x44\x61tatypedefxsd_STRING\x10\x19\x12\x17\n\x13\x44\x61tatypedefxsd_TIME\x10\x1a\x12 \n\x1c\x44\x61tatypedefxsd_UNSIGNED_BYTE\x10\x1b\x12\x1f\n\x1b\x44\x61tatypedefxsd_UNSIGNED_INT\x10\x1c\x12 \n\x1c\x44\x61tatypedefxsd_UNSIGNED_LONG\x10\x1d\x12!\n\x1d\x44\x61tatypedefxsd_UNSIGNED_SHORT\x10\x1e*\x94\x05\n\x10\x44\x61taTypeIec61360\x12 \n\x1c\x44\x61tatypeiec61360_UNSPECIFIED\x10\x00\x12\x19\n\x15\x44\x61tatypeiec61360_DATE\x10\x01\x12\x1b\n\x17\x44\x61tatypeiec61360_STRING\x10\x02\x12(\n$Datatypeiec61360_STRING_TRANSLATABLE\x10\x03\x12$\n Datatypeiec61360_INTEGER_MEASURE\x10\x04\x12"\n\x1e\x44\x61tatypeiec61360_INTEGER_COUNT\x10\x05\x12%\n!Datatypeiec61360_INTEGER_CURRENCY\x10\x06\x12!\n\x1d\x44\x61tatypeiec61360_REAL_MEASURE\x10\x07\x12\x1f\n\x1b\x44\x61tatypeiec61360_REAL_COUNT\x10\x08\x12"\n\x1e\x44\x61tatypeiec61360_REAL_CURRENCY\x10\t\x12\x1c\n\x18\x44\x61tatypeiec61360_BOOLEAN\x10\n\x12\x18\n\x14\x44\x61tatypeiec61360_IRI\x10\x0b\x12\x19\n\x15\x44\x61tatypeiec61360_IRDI\x10\x0c\x12\x1d\n\x19\x44\x61tatypeiec61360_RATIONAL\x10\r\x12%\n!Datatypeiec61360_RATIONAL_MEASURE\x10\x0e\x12\x19\n\x15\x44\x61tatypeiec61360_TIME\x10\x0f\x12\x1e\n\x1a\x44\x61tatypeiec61360_TIMESTAMP\x10\x10\x12\x19\n\x15\x44\x61tatypeiec61360_FILE\x10\x11\x12\x19\n\x15\x44\x61tatypeiec61360_HTML\x10\x12\x12\x19\n\x15\x44\x61tatypeiec61360_BLOB\x10\x13\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "types_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_MODELLINGKIND"]._serialized_start = 20971
    _globals["_MODELLINGKIND"]._serialized_end = 21073
    _globals["_QUALIFIERKIND"]._serialized_start = 21076
    _globals["_QUALIFIERKIND"]._serialized_end = 21232
    _globals["_ASSETKIND"]._serialized_start = 21234
    _globals["_ASSETKIND"]._serialized_end = 21346
    _globals["_AASSUBMODELELEMENTS"]._serialized_start = 21349
    _globals["_AASSUBMODELELEMENTS"]._serialized_end = 22093
    _globals["_ENTITYTYPE"]._serialized_start = 22095
    _globals["_ENTITYTYPE"]._serialized_end = 22205
    _globals["_DIRECTION"]._serialized_start = 22207
    _globals["_DIRECTION"]._serialized_end = 22288
    _globals["_STATEOFEVENT"]._serialized_start = 22290
    _globals["_STATEOFEVENT"]._serialized_end = 22377
    _globals["_REFERENCETYPES"]._serialized_start = 22379
    _globals["_REFERENCETYPES"]._serialized_end = 22502
    _globals["_KEYTYPES"]._serialized_start = 22505
    _globals["_KEYTYPES"]._serialized_end = 23253
    _globals["_DATATYPEDEFXSD"]._serialized_start = 23256
    _globals["_DATATYPEDEFXSD"]._serialized_end = 24209
    _globals["_DATATYPEIEC61360"]._serialized_start = 24212
    _globals["_DATATYPEIEC61360"]._serialized_end = 24872
    _globals["_EXTENSION"]._serialized_start = 27
    _globals["_EXTENSION"]._serialized_end = 311
    _globals["_ADMINISTRATIVEINFORMATION"]._serialized_start = 314
    _globals["_ADMINISTRATIVEINFORMATION"]._serialized_end = 585
    _globals["_QUALIFIER"]._serialized_start = 588
    _globals["_QUALIFIER"]._serialized_end = 923
    _globals["_ASSETADMINISTRATIONSHELL"]._serialized_start = 926
    _globals["_ASSETADMINISTRATIONSHELL"]._serialized_end = 1508
    _globals["_ASSETINFORMATION"]._serialized_start = 1511
    _globals["_ASSETINFORMATION"]._serialized_end = 1792
    _globals["_RESOURCE"]._serialized_start = 1794
    _globals["_RESOURCE"]._serialized_end = 1862
    _globals["_SPECIFICASSETID"]._serialized_start = 1865
    _globals["_SPECIFICASSETID"]._serialized_end = 2112
    _globals["_SUBMODEL"]._serialized_start = 2115
    _globals["_SUBMODEL"]._serialized_end = 2797
    _globals["_RELATIONSHIPELEMENT"]._serialized_start = 2800
    _globals["_RELATIONSHIPELEMENT"]._serialized_end = 3354
    _globals["_SUBMODELELEMENTLIST"]._serialized_start = 3357
    _globals["_SUBMODELELEMENTLIST"]._serialized_end = 4182
    _globals["_SUBMODELELEMENTCOLLECTION"]._serialized_start = 4185
    _globals["_SUBMODELELEMENTCOLLECTION"]._serialized_end = 4720
    _globals["_PROPERTY"]._serialized_start = 4723
    _globals["_PROPERTY"]._serialized_end = 5326
    _globals["_MULTILANGUAGEPROPERTY"]._serialized_start = 5329
    _globals["_MULTILANGUAGEPROPERTY"]._serialized_end = 5914
    _globals["_RANGE"]._serialized_start = 5917
    _globals["_RANGE"]._serialized_end = 6481
    _globals["_REFERENCEELEMENT"]._serialized_start = 6484
    _globals["_REFERENCEELEMENT"]._serialized_end = 7012
    _globals["_BLOB"]._serialized_start = 7015
    _globals["_BLOB"]._serialized_end = 7531
    _globals["_FILE"]._serialized_start = 7534
    _globals["_FILE"]._serialized_end = 8050
    _globals["_ANNOTATEDRELATIONSHIPELEMENT"]._serialized_start = 8053
    _globals["_ANNOTATEDRELATIONSHIPELEMENT"]._serialized_end = 8668
    _globals["_ENTITY"]._serialized_start = 8671
    _globals["_ENTITY"]._serialized_end = 9342
    _globals["_EVENTPAYLOAD"]._serialized_start = 9345
    _globals["_EVENTPAYLOAD"]._serialized_end = 9759
    _globals["_BASICEVENTELEMENT"]._serialized_start = 9762
    _globals["_BASICEVENTELEMENT"]._serialized_end = 10606
    _globals["_OPERATION"]._serialized_start = 10609
    _globals["_OPERATION"]._serialized_end = 11247
    _globals["_OPERATIONVARIABLE"]._serialized_start = 11249
    _globals["_OPERATIONVARIABLE"]._serialized_end = 11318
    _globals["_CAPABILITY"]._serialized_start = 11321
    _globals["_CAPABILITY"]._serialized_end = 11791
    _globals["_CONCEPTDESCRIPTION"]._serialized_start = 11794
    _globals["_CONCEPTDESCRIPTION"]._serialized_end = 12249
    _globals["_REFERENCE"]._serialized_start = 12252
    _globals["_REFERENCE"]._serialized_end = 12416
    _globals["_KEY"]._serialized_start = 12418
    _globals["_KEY"]._serialized_end = 12473
    _globals["_LANGSTRINGNAMETYPE"]._serialized_start = 12475
    _globals["_LANGSTRINGNAMETYPE"]._serialized_end = 12527
    _globals["_LANGSTRINGTEXTTYPE"]._serialized_start = 12529
    _globals["_LANGSTRINGTEXTTYPE"]._serialized_end = 12581
    _globals["_ENVIRONMENT"]._serialized_start = 12584
    _globals["_ENVIRONMENT"]._serialized_end = 12772
    _globals["_EMBEDDEDDATASPECIFICATION"]._serialized_start = 12775
    _globals["_EMBEDDEDDATASPECIFICATION"]._serialized_end = 12932
    _globals["_LEVELTYPE"]._serialized_start = 12934
    _globals["_LEVELTYPE"]._serialized_end = 12997
    _globals["_VALUEREFERENCEPAIR"]._serialized_start = 12999
    _globals["_VALUEREFERENCEPAIR"]._serialized_end = 13074
    _globals["_VALUELIST"]._serialized_start = 13076
    _globals["_VALUELIST"]._serialized_end = 13149
    _globals["_LANGSTRINGPREFERREDNAMETYPEIEC61360"]._serialized_start = 13151
    _globals["_LANGSTRINGPREFERREDNAMETYPEIEC61360"]._serialized_end = 13220
    _globals["_LANGSTRINGSHORTNAMETYPEIEC61360"]._serialized_start = 13222
    _globals["_LANGSTRINGSHORTNAMETYPEIEC61360"]._serialized_end = 13287
    _globals["_LANGSTRINGDEFINITIONTYPEIEC61360"]._serialized_start = 13289
    _globals["_LANGSTRINGDEFINITIONTYPEIEC61360"]._serialized_end = 13355
    _globals["_DATASPECIFICATIONIEC61360"]._serialized_start = 13358
    _globals["_DATASPECIFICATIONIEC61360"]._serialized_end = 14027
    _globals["_HASSEMANTICS_CHOICE"]._serialized_start = 14030
    _globals["_HASSEMANTICS_CHOICE"]._serialized_end = 14988
    _globals["_HASEXTENSIONS_CHOICE"]._serialized_start = 14991
    _globals["_HASEXTENSIONS_CHOICE"]._serialized_end = 15944
    _globals["_REFERABLE_CHOICE"]._serialized_start = 15947
    _globals["_REFERABLE_CHOICE"]._serialized_end = 16896
    _globals["_IDENTIFIABLE_CHOICE"]._serialized_start = 16899
    _globals["_IDENTIFIABLE_CHOICE"]._serialized_end = 17107
    _globals["_HASKIND_CHOICE"]._serialized_start = 17109
    _globals["_HASKIND_CHOICE"]._serialized_end = 17175
    _globals["_HASDATASPECIFICATION_CHOICE"]._serialized_start = 17178
    _globals["_HASDATASPECIFICATION_CHOICE"]._serialized_end = 18214
    _globals["_QUALIFIABLE_CHOICE"]._serialized_start = 18217
    _globals["_QUALIFIABLE_CHOICE"]._serialized_end = 19031
    _globals["_SUBMODELELEMENT_CHOICE"]._serialized_start = 19034
    _globals["_SUBMODELELEMENT_CHOICE"]._serialized_end = 19811
    _globals["_RELATIONSHIPELEMENT_CHOICE"]._serialized_start = 19814
    _globals["_RELATIONSHIPELEMENT_CHOICE"]._serialized_end = 19998
    _globals["_DATAELEMENT_CHOICE"]._serialized_start = 20001
    _globals["_DATAELEMENT_CHOICE"]._serialized_end = 20299
    _globals["_EVENTELEMENT_CHOICE"]._serialized_start = 20301
    _globals["_EVENTELEMENT_CHOICE"]._serialized_end = 20392
    _globals["_ABSTRACTLANGSTRING_CHOICE"]._serialized_start = 20395
    _globals["_ABSTRACTLANGSTRING_CHOICE"]._serialized_end = 20847
    _globals["_DATASPECIFICATIONCONTENT_CHOICE"]._serialized_start = 20849
    _globals["_DATASPECIFICATIONCONTENT_CHOICE"]._serialized_end = 20969
# @@protoc_insertion_point(module_scope)
